@@ -88,6 +88,8 @@ class Analyzer(object):
 		data = loadtxt2d(StringIO(table))
 		if d is not None:
 			d[title.strip().lower()] = data
+		if len(data.shape) == 1:
+			data = numpy.reshape(data, (1,-1))
 		return data
 	
 	def get_stats(self):
@@ -152,17 +154,20 @@ class Analyzer(object):
 		# Global Evidence
 		stats = {'modes':[]}
 		self._read_error_into_dict(lines[0], stats)
-		
-		# backwards compability
-		stats['global evidence'] = stats['Nested Sampling Global Log-Evidence'.lower()]
-		stats['global evidence error'] = stats['Nested Sampling Global Log-Evidence error'.lower()]
 
+		if 'Nested Sampling Global Log-Evidence'.lower() in stats:
+			stats['global evidence'] = stats['Nested Sampling Global Log-Evidence'.lower()]
+			stats['global evidence error'] = stats['Nested Sampling Global Log-Evidence error'.lower()]
+		
 		if 'Nested Importance Sampling Global Log-Evidence' in lines[1]:
 			# INS global evidence
 			self._read_error_into_dict(lines[1], stats)
 			Z = stats['Nested Importance Sampling Global Log-Evidence'.lower()]
 			Zerr = stats['Nested Importance Sampling Global Log-Evidence error'.lower()]
-			# there is only one 'mode'
+			# use INS results in default name
+			stats['global evidence'] = Z
+			stats['global evidence error'] = Zerr
+			
 			text = ''.join(lines[3:])
 			
 			i = 0
